# Copyright (c) 2021-present, Hakan Özler
# All rights reserved.
#
# This source code is licensed under the MIT license found in the
# LICENSE file in the root directory of this source tree.

from .Pelikan import Pelikan
from .Pelikan import main
